#ifndef OSL_LOKI_H
#define OSL_LOKI_H

#include "osl/player.h"

namespace osl
{
  namespace misc
  {
// Int2Type by LOKI
    template<int v>
    struct Int2Type{
      enum { value=v };
    }; 

    template<typename T>
    struct Type2Type{
    }; 

    template<Player P>
    struct Player2Type{
      enum { value=P };
    }; 

    struct EmptyType{};
  } // namespace misc
  using misc::Int2Type;
  using misc::Player2Type;
} // namespace osl
#endif
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:

